@@ -18,7 +18,8 @@
 #include <uuid/uuid.h>
 #include "disk-io.h"
 #include "volumes.h"
-#include "utils.h"
+#include "common/utils.h"
+#include "common/path-utils.h"
 #include "mkfs/common.h"
 #include "convert/common.h"
 
@@ -107,9 +108,11 @@ static int setup_temp_super(int fd, struct btrfs_mkfs_config *cfg,
 			ret = -EINVAL;
 			goto out;
 		}
+		uuid_copy(super->metadata_uuid, super->fsid);
 	} else {
 		uuid_generate(super->fsid);
 		uuid_unparse(super->fsid, cfg->fs_uuid);
+		uuid_copy(super->metadata_uuid, super->fsid);
 	}
 	uuid_generate(chunk_uuid);
 	uuid_unparse(chunk_uuid, cfg->chunk_uuid);
