@@ -20,9 +20,9 @@
 #include "transaction.h"
 #include "print-tree.h"
 #include "repair.h"
-#include "internal.h"
-#include "sizes.h"
-#include "messages.h"
+#include "common/internal.h"
+#include "kernel-lib/sizes.h"
+#include "common/messages.h"
 #include "volumes.h"
 
 static int split_node(struct btrfs_trans_handle *trans, struct btrfs_root
@@ -168,11 +168,6 @@ static int btrfs_block_can_be_shared(struct btrfs_root *root,
 	     btrfs_root_last_snapshot(&root->root_item) ||
 	     btrfs_header_flag(buf, BTRFS_HEADER_FLAG_RELOC)))
 		return 1;
-#ifdef BTRFS_COMPAT_EXTENT_TREE_V0
-        if (root->ref_cows &&
-            btrfs_header_backref_rev(buf) < BTRFS_MIXED_BACKREF_REV)
-                return 1;
-#endif
 	return 0;
 }
 
@@ -3135,7 +3130,7 @@ static int btrfs_uuid_tree_lookup(struct btrfs_root *uuid_root, u8 *uuid,
 		goto out;
 	}
 
-	btrfs_uuid_to_key(uuid, &key.objectid, &key.offset);
+	btrfs_uuid_to_key(uuid, &key);
 	key.type = type;
 	ret = btrfs_search_slot(NULL, uuid_root, &key, path, 0, 0);
 	if (ret < 0) {
@@ -3196,7 +3191,7 @@ int btrfs_uuid_tree_add(struct btrfs_trans_handle *trans, u8 *uuid, u8 type,
 		return ret;
 
 	key.type = type;
-	btrfs_uuid_to_key(uuid, &key.objectid, &key.offset);
+	btrfs_uuid_to_key(uuid, &key);
 
 	path = btrfs_alloc_path();
 	if (!path) {
